# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core/mgmt/v1beta/mgmt.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.healthcheck.v1beta import healthcheck_pb2 as common_dot_healthcheck_dot_v1beta_dot_healthcheck__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x63ore/mgmt/v1beta/mgmt.proto\x12\x10\x63ore.mgmt.v1beta\x1a+common/healthcheck/v1beta/healthcheck.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\"\x95\x01\n\x0fLivenessRequest\x12i\n\x14health_check_request\x18\x01 \x01(\x0b\x32-.common.healthcheck.v1beta.HealthCheckRequestB\x03\xe0\x41\x01H\x00R\x12healthCheckRequest\x88\x01\x01\x42\x17\n\x15_health_check_request\"{\n\x10LivenessResponse\x12g\n\x15health_check_response\x18\x01 \x01(\x0b\x32..common.healthcheck.v1beta.HealthCheckResponseB\x03\xe0\x41\x03R\x13healthCheckResponse\"\x96\x01\n\x10ReadinessRequest\x12i\n\x14health_check_request\x18\x01 \x01(\x0b\x32-.common.healthcheck.v1beta.HealthCheckRequestB\x03\xe0\x41\x01H\x00R\x12healthCheckRequest\x88\x01\x01\x42\x17\n\x15_health_check_request\"|\n\x11ReadinessResponse\x12g\n\x15health_check_response\x18\x01 \x01(\x0b\x32..common.healthcheck.v1beta.HealthCheckResponseB\x03\xe0\x41\x03R\x13healthCheckResponse\",\n\nPermission\x12\x1e\n\x08\x63\x61n_edit\x18\x01 \x01(\x08\x42\x03\xe0\x41\x03R\x07\x63\x61nEdit\"\xcd\x03\n\x0bUserProfile\x12+\n\x0c\x64isplay_name\x18\x01 \x01(\tB\x03\xe0\x41\x01H\x00R\x0b\x64isplayName\x88\x01\x01\x12\x1a\n\x03\x62io\x18\x02 \x01(\tB\x03\xe0\x41\x01H\x01R\x03\x62io\x88\x01\x01\x12 \n\x06\x61vatar\x18\x03 \x01(\tB\x03\xe0\x41\x01H\x02R\x06\x61vatar\x88\x01\x01\x12+\n\x0cpublic_email\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x03R\x0bpublicEmail\x88\x01\x01\x12+\n\x0c\x63ompany_name\x18\x05 \x01(\tB\x03\xe0\x41\x01H\x04R\x0b\x63ompanyName\x88\x01\x01\x12l\n\x14social_profile_links\x18\x06 \x03(\x0b\x32\x35.core.mgmt.v1beta.UserProfile.SocialProfileLinksEntryB\x03\xe0\x41\x01R\x12socialProfileLinks\x1a\x45\n\x17SocialProfileLinksEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x0f\n\r_display_nameB\x06\n\x04_bioB\t\n\x07_avatarB\x0f\n\r_public_emailB\x0f\n\r_company_name\"\x9f\x03\n\x13OrganizationProfile\x12+\n\x0c\x64isplay_name\x18\x01 \x01(\tB\x03\xe0\x41\x01H\x00R\x0b\x64isplayName\x88\x01\x01\x12\x1a\n\x03\x62io\x18\x02 \x01(\tB\x03\xe0\x41\x01H\x01R\x03\x62io\x88\x01\x01\x12 \n\x06\x61vatar\x18\x03 \x01(\tB\x03\xe0\x41\x01H\x02R\x06\x61vatar\x88\x01\x01\x12+\n\x0cpublic_email\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x03R\x0bpublicEmail\x88\x01\x01\x12t\n\x14social_profile_links\x18\x05 \x03(\x0b\x32=.core.mgmt.v1beta.OrganizationProfile.SocialProfileLinksEntryB\x03\xe0\x41\x01R\x12socialProfileLinks\x1a\x45\n\x17SocialProfileLinksEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x0f\n\r_display_nameB\x06\n\x04_bioB\t\n\x07_avatarB\x0f\n\r_public_email\"\x8a\x05\n\x11\x41uthenticatedUser\x12\x17\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x04name\x12\x1a\n\x03uid\x18\x02 \x01(\tB\x03\xe0\x41\x05H\x00R\x03uid\x88\x01\x01\x12\x13\n\x02id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x02id\x12@\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\x12\x19\n\x05\x65mail\x18\x07 \x01(\tB\x03\xe0\x41\x02R\x05\x65mail\x12$\n\x0b\x63ustomer_id\x18\x08 \x01(\tB\x03\xe0\x41\x03R\ncustomerId\x12\x1c\n\x04role\x18\x0c \x01(\tB\x03\xe0\x41\x01H\x01R\x04role\x88\x01\x01\x12<\n\x17newsletter_subscription\x18\r \x01(\x08\x42\x03\xe0\x41\x02R\x16newsletterSubscription\x12+\n\x0c\x63ookie_token\x18\x0e \x01(\tB\x03\xe0\x41\x01H\x02R\x0b\x63ookieToken\x88\x01\x01\x12T\n\x11onboarding_status\x18\x11 \x01(\x0e\x32\".core.mgmt.v1beta.OnboardingStatusB\x03\xe0\x41\x01R\x10onboardingStatus\x12<\n\x07profile\x18\x12 \x01(\x0b\x32\x1d.core.mgmt.v1beta.UserProfileB\x03\xe0\x41\x03R\x07profile:\'\xea\x41$\n\"api.instill.tech/AuthenticatedUserB\x06\n\x04_uidB\x07\n\x05_roleB\x0f\n\r_cookie_token\"\x8e\x01\n\x05Owner\x12\x31\n\x04user\x18\x01 \x01(\x0b\x32\x16.core.mgmt.v1beta.UserB\x03\xe0\x41\x03H\x00R\x04user\x12I\n\x0corganization\x18\x02 \x01(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationB\x03\xe0\x41\x03H\x00R\x0corganizationB\x07\n\x05owner\"\xd4\x02\n\x04User\x12\x17\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x04name\x12\x1a\n\x03uid\x18\x02 \x01(\tB\x03\xe0\x41\x03H\x00R\x03uid\x88\x01\x01\x12\x13\n\x02id\x18\x03 \x01(\tB\x03\xe0\x41\x05R\x02id\x12@\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\x12\x37\n\x07profile\x18\x0b \x01(\x0b\x32\x1d.core.mgmt.v1beta.UserProfileR\x07profile:=\xea\x41:\n\x15\x61pi.instill.tech/User\x12\x0fusers/{user.id}\x12\x10users/{user.uid}B\x06\n\x04_uid\"\xf0\x01\n\x15ListUsersAdminRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x02 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12\x34\n\x04view\x18\x03 \x01(\x0e\x32\x16.core.mgmt.v1beta.ViewB\x03\xe0\x41\x01H\x02R\x04view\x88\x01\x01\x12 \n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x03R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filter\"\x8d\x01\n\x16ListUsersAdminResponse\x12,\n\x05users\x18\x01 \x03(\x0b\x32\x16.core.mgmt.v1beta.UserR\x05users\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"n\n\x13GetUserAdminRequest\x12/\n\x04view\x18\x02 \x01(\x0e\x32\x16.core.mgmt.v1beta.ViewH\x00R\x04view\x88\x01\x01\x12\x17\n\x07user_id\x18\x03 \x01(\tR\x06userIdB\x07\n\x05_viewJ\x04\x08\x01\x10\x02\"B\n\x14GetUserAdminResponse\x12*\n\x04user\x18\x01 \x01(\x0b\x32\x16.core.mgmt.v1beta.UserR\x04user\"s\n\x16LookUpUserAdminRequest\x12/\n\x04view\x18\x02 \x01(\x0e\x32\x16.core.mgmt.v1beta.ViewH\x00R\x04view\x88\x01\x01\x12\x19\n\x08user_uid\x18\x03 \x01(\tR\x07userUidB\x07\n\x05_viewJ\x04\x08\x01\x10\x02\"E\n\x17LookUpUserAdminResponse\x12*\n\x04user\x18\x01 \x01(\x0b\x32\x16.core.mgmt.v1beta.UserR\x04user\"\xe4\x01\n\x1dListOrganizationsAdminRequest\x12 \n\tpage_size\x18\x01 \x01(\x05H\x00R\x08pageSize\x88\x01\x01\x12\"\n\npage_token\x18\x02 \x01(\tH\x01R\tpageToken\x88\x01\x01\x12/\n\x04view\x18\x03 \x01(\x0e\x32\x16.core.mgmt.v1beta.ViewH\x02R\x04view\x88\x01\x01\x12\x1b\n\x06\x66ilter\x18\x04 \x01(\tH\x03R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filter\"\xad\x01\n\x1eListOrganizationsAdminResponse\x12\x44\n\rorganizations\x18\x01 \x03(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationR\rorganizations\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\x86\x01\n\x1bGetOrganizationAdminRequest\x12/\n\x04view\x18\x02 \x01(\x0e\x32\x16.core.mgmt.v1beta.ViewH\x00R\x04view\x88\x01\x01\x12\'\n\x0forganization_id\x18\x03 \x01(\tR\x0eorganizationIdB\x07\n\x05_viewJ\x04\x08\x01\x10\x02\"b\n\x1cGetOrganizationAdminResponse\x12\x42\n\x0corganization\x18\x01 \x01(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationR\x0corganization\"\x8b\x01\n\x1eLookUpOrganizationAdminRequest\x12/\n\x04view\x18\x02 \x01(\x0e\x32\x16.core.mgmt.v1beta.ViewH\x00R\x04view\x88\x01\x01\x12)\n\x10organization_uid\x18\x03 \x01(\tR\x0forganizationUidB\x07\n\x05_viewJ\x04\x08\x01\x10\x02\"e\n\x1fLookUpOrganizationAdminResponse\x12\x42\n\x0corganization\x18\x01 \x01(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationR\x0corganization\"\xeb\x01\n\x10ListUsersRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x02 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12\x34\n\x04view\x18\x03 \x01(\x0e\x32\x16.core.mgmt.v1beta.ViewB\x03\xe0\x41\x01H\x02R\x04view\x88\x01\x01\x12 \n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x03R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filter\"\x97\x01\n\x11ListUsersResponse\x12\x31\n\x05users\x18\x01 \x03(\x0b\x32\x16.core.mgmt.v1beta.UserB\x03\xe0\x41\x03R\x05users\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\"\x8d\x01\n\x0eGetUserRequest\x12\x34\n\x04view\x18\x02 \x01(\x0e\x32\x16.core.mgmt.v1beta.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x12\x36\n\x07user_id\x18\x03 \x01(\tB\x1d\xe0\x41\x02\xfa\x41\x17\n\x15\x61pi.instill.tech/UserR\x06userIdB\x07\n\x05_viewJ\x04\x08\x01\x10\x02\"B\n\x0fGetUserResponse\x12/\n\x04user\x18\x01 \x01(\x0b\x32\x16.core.mgmt.v1beta.UserB\x03\xe0\x41\x03R\x04user\"\x1d\n\x1bGetAuthenticatedUserRequest\"\\\n\x1cGetAuthenticatedUserResponse\x12<\n\x04user\x18\x01 \x01(\x0b\x32#.core.mgmt.v1beta.AuthenticatedUserB\x03\xe0\x41\x03R\x04user\"\x9f\x01\n\x1dPatchAuthenticatedUserRequest\x12<\n\x04user\x18\x01 \x01(\x0b\x32#.core.mgmt.v1beta.AuthenticatedUserB\x03\xe0\x41\x02R\x04user\x12@\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\"^\n\x1ePatchAuthenticatedUserResponse\x12<\n\x04user\x18\x01 \x01(\x0b\x32#.core.mgmt.v1beta.AuthenticatedUserB\x03\xe0\x41\x03R\x04user\",\n\x15\x43heckNamespaceRequest\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\"\xea\x01\n\x16\x43heckNamespaceResponse\x12\x46\n\x04type\x18\x01 \x01(\x0e\x32\x32.core.mgmt.v1beta.CheckNamespaceResponse.NamespaceR\x04type\"\x87\x01\n\tNamespace\x12\x19\n\x15NAMESPACE_UNSPECIFIED\x10\x00\x12\x17\n\x13NAMESPACE_AVAILABLE\x10\x01\x12\x12\n\x0eNAMESPACE_USER\x10\x02\x12\x1a\n\x16NAMESPACE_ORGANIZATION\x10\x03\x12\x16\n\x12NAMESPACE_RESERVED\x10\x04\"1\n\x1a\x43heckNamespaceAdminRequest\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\"\x83\x03\n\x1b\x43heckNamespaceAdminResponse\x12K\n\x04type\x18\x01 \x01(\x0e\x32\x37.core.mgmt.v1beta.CheckNamespaceAdminResponse.NamespaceR\x04type\x12\x10\n\x03uid\x18\x02 \x01(\tR\x03uid\x12,\n\x04user\x18\x03 \x01(\x0b\x32\x16.core.mgmt.v1beta.UserH\x00R\x04user\x12\x44\n\x0corganization\x18\x04 \x01(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationH\x00R\x0corganization\"\x87\x01\n\tNamespace\x12\x19\n\x15NAMESPACE_UNSPECIFIED\x10\x00\x12\x17\n\x13NAMESPACE_AVAILABLE\x10\x01\x12\x12\n\x0eNAMESPACE_USER\x10\x02\x12\x1a\n\x16NAMESPACE_ORGANIZATION\x10\x03\x12\x16\n\x12NAMESPACE_RESERVED\x10\x04\x42\x07\n\x05owner\"8\n\x1f\x43heckNamespaceByUIDAdminRequest\x12\x15\n\x03uid\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x03uid\"\x8b\x03\n CheckNamespaceByUIDAdminResponse\x12P\n\x04type\x18\x01 \x01(\x0e\x32<.core.mgmt.v1beta.CheckNamespaceByUIDAdminResponse.NamespaceR\x04type\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12,\n\x04user\x18\x03 \x01(\x0b\x32\x16.core.mgmt.v1beta.UserH\x00R\x04user\x12\x44\n\x0corganization\x18\x04 \x01(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationH\x00R\x0corganization\"\x87\x01\n\tNamespace\x12\x19\n\x15NAMESPACE_UNSPECIFIED\x10\x00\x12\x17\n\x13NAMESPACE_AVAILABLE\x10\x01\x12\x12\n\x0eNAMESPACE_USER\x10\x02\x12\x1a\n\x16NAMESPACE_ORGANIZATION\x10\x03\x12\x16\n\x12NAMESPACE_RESERVED\x10\x04\x42\x07\n\x05owner\"\xfb\x04\n\x08\x41piToken\x12>\n\rlast_use_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0blastUseTime\x12\x17\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x04name\x12\x15\n\x03uid\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x03uid\x12\x13\n\x02id\x18\x03 \x01(\tB\x03\xe0\x41\x05R\x02id\x12@\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\x12&\n\x0c\x61\x63\x63\x65ss_token\x18\x07 \x01(\tB\x03\xe0\x41\x03R\x0b\x61\x63\x63\x65ssToken\x12;\n\x05state\x18\x08 \x01(\x0e\x32 .core.mgmt.v1beta.ApiToken.StateB\x03\xe0\x41\x03R\x05state\x12\"\n\ntoken_type\x18\t \x01(\tB\x03\xe0\x41\x03R\ttokenType\x12\x17\n\x03ttl\x18\n \x01(\x05\x42\x03\xe0\x41\x04H\x00R\x03ttl\x12=\n\x0b\x65xpire_time\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\nexpireTime\"W\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x12\n\x0eSTATE_INACTIVE\x10\x01\x12\x10\n\x0cSTATE_ACTIVE\x10\x02\x12\x11\n\rSTATE_EXPIRED\x10\x03:\x1e\xea\x41\x1b\n\x19\x61pi.instill.tech/ApiTokenB\x0c\n\nexpiration\"F\n\x12\x43reateTokenRequest\x12\x30\n\x05token\x18\x01 \x01(\x0b\x32\x1a.core.mgmt.v1beta.ApiTokenR\x05token\"L\n\x13\x43reateTokenResponse\x12\x35\n\x05token\x18\x01 \x01(\x0b\x32\x1a.core.mgmt.v1beta.ApiTokenB\x03\xe0\x41\x03R\x05token\"\x80\x01\n\x11ListTokensRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x02 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_token\"\x8f\x01\n\x12ListTokensResponse\x12\x32\n\x06tokens\x18\x01 \x03(\x0b\x32\x1a.core.mgmt.v1beta.ApiTokenR\x06tokens\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"U\n\x0fGetTokenRequest\x12<\n\x08token_id\x18\x02 \x01(\tB!\xe0\x41\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/ApiTokenR\x07tokenIdJ\x04\x08\x01\x10\x02\"I\n\x10GetTokenResponse\x12\x35\n\x05token\x18\x01 \x01(\x0b\x32\x1a.core.mgmt.v1beta.ApiTokenB\x03\xe0\x41\x03R\x05token\"X\n\x12\x44\x65leteTokenRequest\x12<\n\x08token_id\x18\x02 \x01(\tB!\xe0\x41\x02\xfa\x41\x1b\n\x19\x61pi.instill.tech/ApiTokenR\x07tokenIdJ\x04\x08\x01\x10\x02\"\x15\n\x13\x44\x65leteTokenResponse\"\x16\n\x14ValidateTokenRequest\"7\n\x15ValidateTokenResponse\x12\x1e\n\x08user_uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x07userUid\"I\n\x19GetRemainingCreditRequest\x12&\n\x0cnamespace_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceIdJ\x04\x08\x01\x10\x02\"\x8b\x01\n\x1aGetRemainingCreditResponse\x12#\n\nperishable\x18\x02 \x01(\x02\x42\x03\xe0\x41\x03R\nperishable\x12\'\n\x0cimperishable\x18\x03 \x01(\x02\x42\x03\xe0\x41\x03R\x0cimperishable\x12\x19\n\x05total\x18\x04 \x01(\x02\x42\x03\xe0\x41\x03R\x05totalJ\x04\x08\x01\x10\x02\"K\n\x1eGetRemainingCreditAdminRequest\x12#\n\rnamespace_uid\x18\x02 \x01(\tR\x0cnamespaceUidJ\x04\x08\x01\x10\x02\"9\n\x1fGetRemainingCreditAdminResponse\x12\x16\n\x06\x61mount\x18\x01 \x01(\x02R\x06\x61mount\"y\n\x1aSubtractCreditAdminRequest\x12\x16\n\x06\x61mount\x18\x02 \x01(\x02R\x06\x61mount\x12\x18\n\x07\x63oncept\x18\x03 \x01(\tR\x07\x63oncept\x12#\n\rnamespace_uid\x18\x04 \x01(\tR\x0cnamespaceUidJ\x04\x08\x01\x10\x02\"5\n\x1bSubtractCreditAdminResponse\x12\x16\n\x06\x61mount\x18\x01 \x01(\x02R\x06\x61mount\"Z\n\x16\x41uthTokenIssuerRequest\x12\x1f\n\x08username\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x08username\x12\x1f\n\x08password\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08password\"\xec\x01\n\x17\x41uthTokenIssuerResponse\x12`\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\x0b\x32=.core.mgmt.v1beta.AuthTokenIssuerResponse.UnsignedAccessTokenR\x0b\x61\x63\x63\x65ssToken\x1ao\n\x13UnsignedAccessToken\x12\x10\n\x03\x61ud\x18\x01 \x01(\tR\x03\x61ud\x12\x10\n\x03iss\x18\x02 \x01(\tR\x03iss\x12\x10\n\x03sub\x18\x03 \x01(\tR\x03sub\x12\x10\n\x03jti\x18\x04 \x01(\tR\x03jti\x12\x10\n\x03\x65xp\x18\x05 \x01(\x05R\x03\x65xp\"T\n\x10\x41uthLoginRequest\x12\x1f\n\x08username\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x08username\x12\x1f\n\x08password\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08password\"6\n\x11\x41uthLoginResponse\x12!\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tR\x0b\x61\x63\x63\x65ssToken\"\x13\n\x11\x41uthLogoutRequest\"\x14\n\x12\x41uthLogoutResponse\" \n\x1e\x41uthValidateAccessTokenRequest\"!\n\x1f\x41uthValidateAccessTokenResponse\"a\n\x19\x41uthChangePasswordRequest\x12!\n\x0cold_password\x18\x01 \x01(\tR\x0boldPassword\x12!\n\x0cnew_password\x18\x02 \x01(\tR\x0bnewPassword\"\x1c\n\x1a\x41uthChangePasswordResponse\"\xd8\x03\n\x0cOrganization\x12\x17\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x04name\x12\x15\n\x03uid\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x03uid\x12\x13\n\x02id\x18\x03 \x01(\tB\x03\xe0\x41\x05R\x02id\x12@\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\x12\x31\n\x05owner\x18\x0b \x01(\x0b\x32\x16.core.mgmt.v1beta.UserB\x03\xe0\x41\x03R\x05owner\x12\x44\n\x07profile\x18\x0c \x01(\x0b\x32%.core.mgmt.v1beta.OrganizationProfileB\x03\xe0\x41\x02R\x07profile\x12\x41\n\npermission\x18\r \x01(\x0b\x32\x1c.core.mgmt.v1beta.PermissionB\x03\xe0\x41\x03R\npermission:C\xea\x41@\n\x1d\x61pi.instill.tech/Organization\x12\x1forganizations/{organization.id}\"\xf3\x01\n\x18ListOrganizationsRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x02 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12\x34\n\x04view\x18\x03 \x01(\x0e\x32\x16.core.mgmt.v1beta.ViewB\x03\xe0\x41\x01H\x02R\x04view\x88\x01\x01\x12 \n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x03R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\x07\n\x05_viewB\t\n\x07_filter\"\xb7\x01\n\x19ListOrganizationsResponse\x12I\n\rorganizations\x18\x01 \x03(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationB\x03\xe0\x41\x03R\rorganizations\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\"_\n\x19\x43reateOrganizationRequest\x12\x42\n\x0corganization\x18\x01 \x01(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationR\x0corganization\"e\n\x1a\x43reateOrganizationResponse\x12G\n\x0corganization\x18\x01 \x01(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationB\x03\xe0\x41\x03R\x0corganization\"\xad\x01\n\x16GetOrganizationRequest\x12\x34\n\x04view\x18\x02 \x01(\x0e\x32\x16.core.mgmt.v1beta.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x12N\n\x0forganization_id\x18\x03 \x01(\tB%\xe0\x41\x02\xfa\x41\x1f\n\x1d\x61pi.instill.tech/OrganizationR\x0eorganizationIdB\x07\n\x05_viewJ\x04\x08\x01\x10\x02\"b\n\x17GetOrganizationResponse\x12G\n\x0corganization\x18\x01 \x01(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationB\x03\xe0\x41\x03R\x0corganization\"\xcf\x01\n\x19UpdateOrganizationRequest\x12\x42\n\x0corganization\x18\x01 \x01(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationR\x0corganization\x12@\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\x12,\n\x0forganization_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x0eorganizationId\"e\n\x1aUpdateOrganizationResponse\x12G\n\x0corganization\x18\x01 \x01(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationB\x03\xe0\x41\x03R\x0corganization\"q\n\x19\x44\x65leteOrganizationRequest\x12N\n\x0forganization_id\x18\x02 \x01(\tB%\xe0\x41\x02\xfa\x41\x1f\n\x1d\x61pi.instill.tech/OrganizationR\x0eorganizationIdJ\x04\x08\x01\x10\x02\"\x1c\n\x1a\x44\x65leteOrganizationResponse\"\xa7\x02\n\x16OrganizationMembership\x12<\n\x04name\x18\x01 \x01(\tB(\x92\x41\"\xca>\x1f\xfa\x02\x1corganization_membership_name\xe0\x41\x03R\x04name\x12\x17\n\x04role\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x04role\x12<\n\x05state\x18\x04 \x01(\x0e\x32!.core.mgmt.v1beta.MembershipStateB\x03\xe0\x41\x03R\x05state\x12/\n\x04user\x18\x05 \x01(\x0b\x32\x16.core.mgmt.v1beta.UserB\x03\xe0\x41\x03R\x04user\x12G\n\x0corganization\x18\x06 \x01(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationB\x03\xe0\x41\x03R\x0corganization\"\x97\x02\n\x0eUserMembership\x12\x34\n\x04name\x18\x01 \x01(\tB \x92\x41\x1a\xca>\x17\xfa\x02\x14user_membership_name\xe0\x41\x03R\x04name\x12\x17\n\x04role\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x04role\x12<\n\x05state\x18\x04 \x01(\x0e\x32!.core.mgmt.v1beta.MembershipStateB\x03\xe0\x41\x02R\x05state\x12/\n\x04user\x18\x05 \x01(\x0b\x32\x16.core.mgmt.v1beta.UserB\x03\xe0\x41\x03R\x04user\x12G\n\x0corganization\x18\x06 \x01(\x0b\x32\x1e.core.mgmt.v1beta.OrganizationB\x03\xe0\x41\x03R\x0corganization\"@\n\x1aListUserMembershipsRequest\x12\x1c\n\x07user_id\x18\x06 \x01(\tB\x03\xe0\x41\x02R\x06userIdJ\x04\x08\x05\x10\x06\"f\n\x1bListUserMembershipsResponse\x12G\n\x0bmemberships\x18\x01 \x03(\x0b\x32 .core.mgmt.v1beta.UserMembershipB\x03\xe0\x41\x03R\x0bmemberships\"\xab\x01\n\x18GetUserMembershipRequest\x12\x34\n\x04view\x18\x02 \x01(\x0e\x32\x16.core.mgmt.v1beta.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x12\x1c\n\x07user_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x06userId\x12,\n\x0forganization_id\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x0eorganizationIdB\x07\n\x05_viewJ\x04\x08\x01\x10\x02\"b\n\x19GetUserMembershipResponse\x12\x45\n\nmembership\x18\x01 \x01(\x0b\x32 .core.mgmt.v1beta.UserMembershipB\x03\xe0\x41\x03R\nmembership\"\xf2\x01\n\x1bUpdateUserMembershipRequest\x12\x45\n\nmembership\x18\x01 \x01(\x0b\x32 .core.mgmt.v1beta.UserMembershipB\x03\xe0\x41\x02R\nmembership\x12@\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\x12\x1c\n\x07user_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x06userId\x12,\n\x0forganization_id\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x0eorganizationId\"e\n\x1cUpdateUserMembershipResponse\x12\x45\n\nmembership\x18\x01 \x01(\x0b\x32 .core.mgmt.v1beta.UserMembershipB\x03\xe0\x41\x03R\nmembership\"o\n\x1b\x44\x65leteUserMembershipRequest\x12\x1c\n\x07user_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x06userId\x12,\n\x0forganization_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x0eorganizationIdJ\x04\x08\x01\x10\x02\"\x1e\n\x1c\x44\x65leteUserMembershipResponse\"X\n\"ListOrganizationMembershipsRequest\x12,\n\x0forganization_id\x18\x06 \x01(\tB\x03\xe0\x41\x02R\x0eorganizationIdJ\x04\x08\x05\x10\x06\"v\n#ListOrganizationMembershipsResponse\x12O\n\x0bmemberships\x18\x01 \x03(\x0b\x32(.core.mgmt.v1beta.OrganizationMembershipB\x03\xe0\x41\x03R\x0bmemberships\"\xb3\x01\n GetOrganizationMembershipRequest\x12\x34\n\x04view\x18\x02 \x01(\x0e\x32\x16.core.mgmt.v1beta.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x12,\n\x0forganization_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x0eorganizationId\x12\x1c\n\x07user_id\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x06userIdB\x07\n\x05_viewJ\x04\x08\x01\x10\x02\"r\n!GetOrganizationMembershipResponse\x12M\n\nmembership\x18\x01 \x01(\x0b\x32(.core.mgmt.v1beta.OrganizationMembershipB\x03\xe0\x41\x03R\nmembership\"\x82\x02\n#UpdateOrganizationMembershipRequest\x12M\n\nmembership\x18\x01 \x01(\x0b\x32(.core.mgmt.v1beta.OrganizationMembershipB\x03\xe0\x41\x02R\nmembership\x12@\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\x12,\n\x0forganization_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x0eorganizationId\x12\x1c\n\x07user_id\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x06userId\"u\n$UpdateOrganizationMembershipResponse\x12M\n\nmembership\x18\x01 \x01(\x0b\x32(.core.mgmt.v1beta.OrganizationMembershipB\x03\xe0\x41\x03R\nmembership\"w\n#DeleteOrganizationMembershipRequest\x12,\n\x0forganization_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0eorganizationId\x12\x1c\n\x07user_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x06userIdJ\x04\x08\x01\x10\x02\"&\n$DeleteOrganizationMembershipResponse\"\xc8\x04\n\x18StripeSubscriptionDetail\x12&\n\x0cproduct_name\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x0bproductName\x12\x13\n\x02id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x02id\x12\x1c\n\x07item_id\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x06itemId\x12\x19\n\x05price\x18\x04 \x01(\x02\x42\x03\xe0\x41\x03R\x05price\x12)\n\x0b\x63\x61nceled_at\x18\x05 \x01(\x05\x42\x03\xe0\x41\x03H\x00R\ncanceledAt\x88\x01\x01\x12%\n\ttrial_end\x18\x06 \x01(\x05\x42\x03\xe0\x41\x03H\x01R\x08trialEnd\x88\x01\x01\x12N\n\x06status\x18\x07 \x01(\x0e\x32\x31.core.mgmt.v1beta.StripeSubscriptionDetail.StatusB\x03\xe0\x41\x03R\x06status\x12%\n\x0b\x64\x65scription\x18\x08 \x01(\tB\x03\xe0\x41\x03R\x0b\x64\x65scription\"\xce\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x15\n\x11STATUS_INCOMPLETE\x10\x01\x12\x1d\n\x19STATUS_INCOMPLETE_EXPIRED\x10\x02\x12\x13\n\x0fSTATUS_TRIALING\x10\x03\x12\x11\n\rSTATUS_ACTIVE\x10\x04\x12\x13\n\x0fSTATUS_PAST_DUE\x10\x05\x12\x13\n\x0fSTATUS_CANCELED\x10\x06\x12\x11\n\rSTATUS_UNPAID\x10\x07\x12\x11\n\rSTATUS_PAUSED\x10\x08\x42\x0e\n\x0c_canceled_atB\x0c\n\n_trial_end\"\xd8\x01\n\x10UserSubscription\x12@\n\x04plan\x18\x01 \x01(\x0e\x32\'.core.mgmt.v1beta.UserSubscription.PlanB\x03\xe0\x41\x03R\x04plan\x12G\n\x06\x64\x65tail\x18\x02 \x01(\x0b\x32*.core.mgmt.v1beta.StripeSubscriptionDetailB\x03\xe0\x41\x03R\x06\x64\x65tail\"9\n\x04Plan\x12\x14\n\x10PLAN_UNSPECIFIED\x10\x00\x12\r\n\tPLAN_FREE\x10\x01\x12\x0c\n\x08PLAN_PRO\x10\x02\"\xa8\x02\n\x18OrganizationSubscription\x12H\n\x04plan\x18\x01 \x01(\x0e\x32/.core.mgmt.v1beta.OrganizationSubscription.PlanB\x03\xe0\x41\x03R\x04plan\x12G\n\x06\x64\x65tail\x18\x02 \x01(\x0b\x32*.core.mgmt.v1beta.StripeSubscriptionDetailB\x03\xe0\x41\x03R\x06\x64\x65tail\x12\"\n\nused_seats\x18\x04 \x01(\x05\x42\x03\xe0\x41\x03R\tusedSeats\"O\n\x04Plan\x12\x14\n\x10PLAN_UNSPECIFIED\x10\x00\x12\r\n\tPLAN_FREE\x10\x01\x12\r\n\tPLAN_TEAM\x10\x02\x12\x13\n\x0fPLAN_ENTERPRISE\x10\x03J\x04\x08\x03\x10\x04\")\n\'GetAuthenticatedUserSubscriptionRequest\"w\n(GetAuthenticatedUserSubscriptionResponse\x12K\n\x0csubscription\x18\x01 \x01(\x0b\x32\".core.mgmt.v1beta.UserSubscriptionB\x03\xe0\x41\x03R\x0csubscription\"X\n\"GetOrganizationSubscriptionRequest\x12,\n\x0forganization_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0eorganizationIdJ\x04\x08\x01\x10\x02\"z\n#GetOrganizationSubscriptionResponse\x12S\n\x0csubscription\x18\x01 \x01(\x0b\x32*.core.mgmt.v1beta.OrganizationSubscriptionB\x03\xe0\x41\x03R\x0csubscription\"@\n\x1fGetUserSubscriptionAdminRequest\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userIdJ\x04\x08\x01\x10\x02\"j\n GetUserSubscriptionAdminResponse\x12\x46\n\x0csubscription\x18\x01 \x01(\x0b\x32\".core.mgmt.v1beta.UserSubscriptionR\x0csubscription\"X\n\'GetOrganizationSubscriptionAdminRequest\x12\'\n\x0forganization_id\x18\x02 \x01(\tR\x0eorganizationIdJ\x04\x08\x01\x10\x02\"z\n(GetOrganizationSubscriptionAdminResponse\x12N\n\x0csubscription\x18\x01 \x01(\x0b\x32*.core.mgmt.v1beta.OrganizationSubscriptionR\x0csubscription*;\n\x04View\x12\x14\n\x10VIEW_UNSPECIFIED\x10\x00\x12\x0e\n\nVIEW_BASIC\x10\x01\x12\r\n\tVIEW_FULL\x10\x02*Y\n\tOwnerType\x12\x1a\n\x16OWNER_TYPE_UNSPECIFIED\x10\x00\x12\x13\n\x0fOWNER_TYPE_USER\x10\x01\x12\x1b\n\x17OWNER_TYPE_ORGANIZATION\x10\x02*n\n\x0fMembershipState\x12 \n\x1cMEMBERSHIP_STATE_UNSPECIFIED\x10\x00\x12\x1b\n\x17MEMBERSHIP_STATE_ACTIVE\x10\x01\x12\x1c\n\x18MEMBERSHIP_STATE_PENDING\x10\x02*y\n\x10OnboardingStatus\x12!\n\x1dONBOARDING_STATUS_UNSPECIFIED\x10\x00\x12!\n\x1dONBOARDING_STATUS_IN_PROGRESS\x10\x01\x12\x1f\n\x1bONBOARDING_STATUS_COMPLETED\x10\x02\x42\xc2\x01\n\x14\x63om.core.mgmt.v1betaB\tMgmtProtoP\x01Z=github.com/instill-ai/protogen-go/core/mgmt/v1beta;mgmtv1beta\xa2\x02\x03\x43MX\xaa\x02\x10\x43ore.Mgmt.V1beta\xca\x02\x10\x43ore\\Mgmt\\V1beta\xe2\x02\x1c\x43ore\\Mgmt\\V1beta\\GPBMetadata\xea\x02\x12\x43ore::Mgmt::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core.mgmt.v1beta.mgmt_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024com.core.mgmt.v1betaB\tMgmtProtoP\001Z=github.com/instill-ai/protogen-go/core/mgmt/v1beta;mgmtv1beta\242\002\003CMX\252\002\020Core.Mgmt.V1beta\312\002\020Core\\Mgmt\\V1beta\342\002\034Core\\Mgmt\\V1beta\\GPBMetadata\352\002\022Core::Mgmt::V1beta'
  _LIVENESSREQUEST.fields_by_name['health_check_request']._options = None
  _LIVENESSREQUEST.fields_by_name['health_check_request']._serialized_options = b'\340A\001'
  _LIVENESSRESPONSE.fields_by_name['health_check_response']._options = None
  _LIVENESSRESPONSE.fields_by_name['health_check_response']._serialized_options = b'\340A\003'
  _READINESSREQUEST.fields_by_name['health_check_request']._options = None
  _READINESSREQUEST.fields_by_name['health_check_request']._serialized_options = b'\340A\001'
  _READINESSRESPONSE.fields_by_name['health_check_response']._options = None
  _READINESSRESPONSE.fields_by_name['health_check_response']._serialized_options = b'\340A\003'
  _PERMISSION.fields_by_name['can_edit']._options = None
  _PERMISSION.fields_by_name['can_edit']._serialized_options = b'\340A\003'
  _USERPROFILE_SOCIALPROFILELINKSENTRY._options = None
  _USERPROFILE_SOCIALPROFILELINKSENTRY._serialized_options = b'8\001'
  _USERPROFILE.fields_by_name['display_name']._options = None
  _USERPROFILE.fields_by_name['display_name']._serialized_options = b'\340A\001'
  _USERPROFILE.fields_by_name['bio']._options = None
  _USERPROFILE.fields_by_name['bio']._serialized_options = b'\340A\001'
  _USERPROFILE.fields_by_name['avatar']._options = None
  _USERPROFILE.fields_by_name['avatar']._serialized_options = b'\340A\001'
  _USERPROFILE.fields_by_name['public_email']._options = None
  _USERPROFILE.fields_by_name['public_email']._serialized_options = b'\340A\001'
  _USERPROFILE.fields_by_name['company_name']._options = None
  _USERPROFILE.fields_by_name['company_name']._serialized_options = b'\340A\001'
  _USERPROFILE.fields_by_name['social_profile_links']._options = None
  _USERPROFILE.fields_by_name['social_profile_links']._serialized_options = b'\340A\001'
  _ORGANIZATIONPROFILE_SOCIALPROFILELINKSENTRY._options = None
  _ORGANIZATIONPROFILE_SOCIALPROFILELINKSENTRY._serialized_options = b'8\001'
  _ORGANIZATIONPROFILE.fields_by_name['display_name']._options = None
  _ORGANIZATIONPROFILE.fields_by_name['display_name']._serialized_options = b'\340A\001'
  _ORGANIZATIONPROFILE.fields_by_name['bio']._options = None
  _ORGANIZATIONPROFILE.fields_by_name['bio']._serialized_options = b'\340A\001'
  _ORGANIZATIONPROFILE.fields_by_name['avatar']._options = None
  _ORGANIZATIONPROFILE.fields_by_name['avatar']._serialized_options = b'\340A\001'
  _ORGANIZATIONPROFILE.fields_by_name['public_email']._options = None
  _ORGANIZATIONPROFILE.fields_by_name['public_email']._serialized_options = b'\340A\001'
  _ORGANIZATIONPROFILE.fields_by_name['social_profile_links']._options = None
  _ORGANIZATIONPROFILE.fields_by_name['social_profile_links']._serialized_options = b'\340A\001'
  _AUTHENTICATEDUSER.fields_by_name['name']._options = None
  _AUTHENTICATEDUSER.fields_by_name['name']._serialized_options = b'\340A\003'
  _AUTHENTICATEDUSER.fields_by_name['uid']._options = None
  _AUTHENTICATEDUSER.fields_by_name['uid']._serialized_options = b'\340A\005'
  _AUTHENTICATEDUSER.fields_by_name['id']._options = None
  _AUTHENTICATEDUSER.fields_by_name['id']._serialized_options = b'\340A\002'
  _AUTHENTICATEDUSER.fields_by_name['create_time']._options = None
  _AUTHENTICATEDUSER.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _AUTHENTICATEDUSER.fields_by_name['update_time']._options = None
  _AUTHENTICATEDUSER.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _AUTHENTICATEDUSER.fields_by_name['email']._options = None
  _AUTHENTICATEDUSER.fields_by_name['email']._serialized_options = b'\340A\002'
  _AUTHENTICATEDUSER.fields_by_name['customer_id']._options = None
  _AUTHENTICATEDUSER.fields_by_name['customer_id']._serialized_options = b'\340A\003'
  _AUTHENTICATEDUSER.fields_by_name['role']._options = None
  _AUTHENTICATEDUSER.fields_by_name['role']._serialized_options = b'\340A\001'
  _AUTHENTICATEDUSER.fields_by_name['newsletter_subscription']._options = None
  _AUTHENTICATEDUSER.fields_by_name['newsletter_subscription']._serialized_options = b'\340A\002'
  _AUTHENTICATEDUSER.fields_by_name['cookie_token']._options = None
  _AUTHENTICATEDUSER.fields_by_name['cookie_token']._serialized_options = b'\340A\001'
  _AUTHENTICATEDUSER.fields_by_name['onboarding_status']._options = None
  _AUTHENTICATEDUSER.fields_by_name['onboarding_status']._serialized_options = b'\340A\001'
  _AUTHENTICATEDUSER.fields_by_name['profile']._options = None
  _AUTHENTICATEDUSER.fields_by_name['profile']._serialized_options = b'\340A\003'
  _AUTHENTICATEDUSER._options = None
  _AUTHENTICATEDUSER._serialized_options = b'\352A$\n\"api.instill.tech/AuthenticatedUser'
  _OWNER.fields_by_name['user']._options = None
  _OWNER.fields_by_name['user']._serialized_options = b'\340A\003'
  _OWNER.fields_by_name['organization']._options = None
  _OWNER.fields_by_name['organization']._serialized_options = b'\340A\003'
  _USER.fields_by_name['name']._options = None
  _USER.fields_by_name['name']._serialized_options = b'\340A\003'
  _USER.fields_by_name['uid']._options = None
  _USER.fields_by_name['uid']._serialized_options = b'\340A\003'
  _USER.fields_by_name['id']._options = None
  _USER.fields_by_name['id']._serialized_options = b'\340A\005'
  _USER.fields_by_name['create_time']._options = None
  _USER.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _USER.fields_by_name['update_time']._options = None
  _USER.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _USER._options = None
  _USER._serialized_options = b'\352A:\n\025api.instill.tech/User\022\017users/{user.id}\022\020users/{user.uid}'
  _LISTUSERSADMINREQUEST.fields_by_name['page_size']._options = None
  _LISTUSERSADMINREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTUSERSADMINREQUEST.fields_by_name['page_token']._options = None
  _LISTUSERSADMINREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTUSERSADMINREQUEST.fields_by_name['view']._options = None
  _LISTUSERSADMINREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _LISTUSERSADMINREQUEST.fields_by_name['filter']._options = None
  _LISTUSERSADMINREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTUSERSREQUEST.fields_by_name['page_size']._options = None
  _LISTUSERSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTUSERSREQUEST.fields_by_name['page_token']._options = None
  _LISTUSERSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTUSERSREQUEST.fields_by_name['view']._options = None
  _LISTUSERSREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _LISTUSERSREQUEST.fields_by_name['filter']._options = None
  _LISTUSERSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTUSERSRESPONSE.fields_by_name['users']._options = None
  _LISTUSERSRESPONSE.fields_by_name['users']._serialized_options = b'\340A\003'
  _LISTUSERSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTUSERSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTUSERSRESPONSE.fields_by_name['total_size']._options = None
  _LISTUSERSRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _GETUSERREQUEST.fields_by_name['view']._options = None
  _GETUSERREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _GETUSERREQUEST.fields_by_name['user_id']._options = None
  _GETUSERREQUEST.fields_by_name['user_id']._serialized_options = b'\340A\002\372A\027\n\025api.instill.tech/User'
  _GETUSERRESPONSE.fields_by_name['user']._options = None
  _GETUSERRESPONSE.fields_by_name['user']._serialized_options = b'\340A\003'
  _GETAUTHENTICATEDUSERRESPONSE.fields_by_name['user']._options = None
  _GETAUTHENTICATEDUSERRESPONSE.fields_by_name['user']._serialized_options = b'\340A\003'
  _PATCHAUTHENTICATEDUSERREQUEST.fields_by_name['user']._options = None
  _PATCHAUTHENTICATEDUSERREQUEST.fields_by_name['user']._serialized_options = b'\340A\002'
  _PATCHAUTHENTICATEDUSERREQUEST.fields_by_name['update_mask']._options = None
  _PATCHAUTHENTICATEDUSERREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _PATCHAUTHENTICATEDUSERRESPONSE.fields_by_name['user']._options = None
  _PATCHAUTHENTICATEDUSERRESPONSE.fields_by_name['user']._serialized_options = b'\340A\003'
  _CHECKNAMESPACEREQUEST.fields_by_name['id']._options = None
  _CHECKNAMESPACEREQUEST.fields_by_name['id']._serialized_options = b'\340A\002'
  _CHECKNAMESPACEADMINREQUEST.fields_by_name['id']._options = None
  _CHECKNAMESPACEADMINREQUEST.fields_by_name['id']._serialized_options = b'\340A\002'
  _CHECKNAMESPACEBYUIDADMINREQUEST.fields_by_name['uid']._options = None
  _CHECKNAMESPACEBYUIDADMINREQUEST.fields_by_name['uid']._serialized_options = b'\340A\002'
  _APITOKEN.fields_by_name['name']._options = None
  _APITOKEN.fields_by_name['name']._serialized_options = b'\340A\003'
  _APITOKEN.fields_by_name['uid']._options = None
  _APITOKEN.fields_by_name['uid']._serialized_options = b'\340A\003'
  _APITOKEN.fields_by_name['id']._options = None
  _APITOKEN.fields_by_name['id']._serialized_options = b'\340A\005'
  _APITOKEN.fields_by_name['create_time']._options = None
  _APITOKEN.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _APITOKEN.fields_by_name['update_time']._options = None
  _APITOKEN.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _APITOKEN.fields_by_name['access_token']._options = None
  _APITOKEN.fields_by_name['access_token']._serialized_options = b'\340A\003'
  _APITOKEN.fields_by_name['state']._options = None
  _APITOKEN.fields_by_name['state']._serialized_options = b'\340A\003'
  _APITOKEN.fields_by_name['token_type']._options = None
  _APITOKEN.fields_by_name['token_type']._serialized_options = b'\340A\003'
  _APITOKEN.fields_by_name['ttl']._options = None
  _APITOKEN.fields_by_name['ttl']._serialized_options = b'\340A\004'
  _APITOKEN._options = None
  _APITOKEN._serialized_options = b'\352A\033\n\031api.instill.tech/ApiToken'
  _CREATETOKENRESPONSE.fields_by_name['token']._options = None
  _CREATETOKENRESPONSE.fields_by_name['token']._serialized_options = b'\340A\003'
  _LISTTOKENSREQUEST.fields_by_name['page_size']._options = None
  _LISTTOKENSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTTOKENSREQUEST.fields_by_name['page_token']._options = None
  _LISTTOKENSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _GETTOKENREQUEST.fields_by_name['token_id']._options = None
  _GETTOKENREQUEST.fields_by_name['token_id']._serialized_options = b'\340A\002\372A\033\n\031api.instill.tech/ApiToken'
  _GETTOKENRESPONSE.fields_by_name['token']._options = None
  _GETTOKENRESPONSE.fields_by_name['token']._serialized_options = b'\340A\003'
  _DELETETOKENREQUEST.fields_by_name['token_id']._options = None
  _DELETETOKENREQUEST.fields_by_name['token_id']._serialized_options = b'\340A\002\372A\033\n\031api.instill.tech/ApiToken'
  _VALIDATETOKENRESPONSE.fields_by_name['user_uid']._options = None
  _VALIDATETOKENRESPONSE.fields_by_name['user_uid']._serialized_options = b'\340A\003'
  _GETREMAININGCREDITREQUEST.fields_by_name['namespace_id']._options = None
  _GETREMAININGCREDITREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _GETREMAININGCREDITRESPONSE.fields_by_name['perishable']._options = None
  _GETREMAININGCREDITRESPONSE.fields_by_name['perishable']._serialized_options = b'\340A\003'
  _GETREMAININGCREDITRESPONSE.fields_by_name['imperishable']._options = None
  _GETREMAININGCREDITRESPONSE.fields_by_name['imperishable']._serialized_options = b'\340A\003'
  _GETREMAININGCREDITRESPONSE.fields_by_name['total']._options = None
  _GETREMAININGCREDITRESPONSE.fields_by_name['total']._serialized_options = b'\340A\003'
  _AUTHTOKENISSUERREQUEST.fields_by_name['username']._options = None
  _AUTHTOKENISSUERREQUEST.fields_by_name['username']._serialized_options = b'\340A\002'
  _AUTHTOKENISSUERREQUEST.fields_by_name['password']._options = None
  _AUTHTOKENISSUERREQUEST.fields_by_name['password']._serialized_options = b'\340A\002'
  _AUTHLOGINREQUEST.fields_by_name['username']._options = None
  _AUTHLOGINREQUEST.fields_by_name['username']._serialized_options = b'\340A\002'
  _AUTHLOGINREQUEST.fields_by_name['password']._options = None
  _AUTHLOGINREQUEST.fields_by_name['password']._serialized_options = b'\340A\002'
  _ORGANIZATION.fields_by_name['name']._options = None
  _ORGANIZATION.fields_by_name['name']._serialized_options = b'\340A\003'
  _ORGANIZATION.fields_by_name['uid']._options = None
  _ORGANIZATION.fields_by_name['uid']._serialized_options = b'\340A\003'
  _ORGANIZATION.fields_by_name['id']._options = None
  _ORGANIZATION.fields_by_name['id']._serialized_options = b'\340A\005'
  _ORGANIZATION.fields_by_name['create_time']._options = None
  _ORGANIZATION.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _ORGANIZATION.fields_by_name['update_time']._options = None
  _ORGANIZATION.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _ORGANIZATION.fields_by_name['owner']._options = None
  _ORGANIZATION.fields_by_name['owner']._serialized_options = b'\340A\003'
  _ORGANIZATION.fields_by_name['profile']._options = None
  _ORGANIZATION.fields_by_name['profile']._serialized_options = b'\340A\002'
  _ORGANIZATION.fields_by_name['permission']._options = None
  _ORGANIZATION.fields_by_name['permission']._serialized_options = b'\340A\003'
  _ORGANIZATION._options = None
  _ORGANIZATION._serialized_options = b'\352A@\n\035api.instill.tech/Organization\022\037organizations/{organization.id}'
  _LISTORGANIZATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTORGANIZATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTORGANIZATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONSREQUEST.fields_by_name['view']._options = None
  _LISTORGANIZATIONSREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONSREQUEST.fields_by_name['filter']._options = None
  _LISTORGANIZATIONSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTORGANIZATIONSRESPONSE.fields_by_name['organizations']._options = None
  _LISTORGANIZATIONSRESPONSE.fields_by_name['organizations']._serialized_options = b'\340A\003'
  _LISTORGANIZATIONSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTORGANIZATIONSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTORGANIZATIONSRESPONSE.fields_by_name['total_size']._options = None
  _LISTORGANIZATIONSRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _CREATEORGANIZATIONRESPONSE.fields_by_name['organization']._options = None
  _CREATEORGANIZATIONRESPONSE.fields_by_name['organization']._serialized_options = b'\340A\003'
  _GETORGANIZATIONREQUEST.fields_by_name['view']._options = None
  _GETORGANIZATIONREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _GETORGANIZATIONREQUEST.fields_by_name['organization_id']._options = None
  _GETORGANIZATIONREQUEST.fields_by_name['organization_id']._serialized_options = b'\340A\002\372A\037\n\035api.instill.tech/Organization'
  _GETORGANIZATIONRESPONSE.fields_by_name['organization']._options = None
  _GETORGANIZATIONRESPONSE.fields_by_name['organization']._serialized_options = b'\340A\003'
  _UPDATEORGANIZATIONREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEORGANIZATIONREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _UPDATEORGANIZATIONREQUEST.fields_by_name['organization_id']._options = None
  _UPDATEORGANIZATIONREQUEST.fields_by_name['organization_id']._serialized_options = b'\340A\002'
  _UPDATEORGANIZATIONRESPONSE.fields_by_name['organization']._options = None
  _UPDATEORGANIZATIONRESPONSE.fields_by_name['organization']._serialized_options = b'\340A\003'
  _DELETEORGANIZATIONREQUEST.fields_by_name['organization_id']._options = None
  _DELETEORGANIZATIONREQUEST.fields_by_name['organization_id']._serialized_options = b'\340A\002\372A\037\n\035api.instill.tech/Organization'
  _ORGANIZATIONMEMBERSHIP.fields_by_name['name']._options = None
  _ORGANIZATIONMEMBERSHIP.fields_by_name['name']._serialized_options = b'\222A\"\312>\037\372\002\034organization_membership_name\340A\003'
  _ORGANIZATIONMEMBERSHIP.fields_by_name['role']._options = None
  _ORGANIZATIONMEMBERSHIP.fields_by_name['role']._serialized_options = b'\340A\002'
  _ORGANIZATIONMEMBERSHIP.fields_by_name['state']._options = None
  _ORGANIZATIONMEMBERSHIP.fields_by_name['state']._serialized_options = b'\340A\003'
  _ORGANIZATIONMEMBERSHIP.fields_by_name['user']._options = None
  _ORGANIZATIONMEMBERSHIP.fields_by_name['user']._serialized_options = b'\340A\003'
  _ORGANIZATIONMEMBERSHIP.fields_by_name['organization']._options = None
  _ORGANIZATIONMEMBERSHIP.fields_by_name['organization']._serialized_options = b'\340A\003'
  _USERMEMBERSHIP.fields_by_name['name']._options = None
  _USERMEMBERSHIP.fields_by_name['name']._serialized_options = b'\222A\032\312>\027\372\002\024user_membership_name\340A\003'
  _USERMEMBERSHIP.fields_by_name['role']._options = None
  _USERMEMBERSHIP.fields_by_name['role']._serialized_options = b'\340A\003'
  _USERMEMBERSHIP.fields_by_name['state']._options = None
  _USERMEMBERSHIP.fields_by_name['state']._serialized_options = b'\340A\002'
  _USERMEMBERSHIP.fields_by_name['user']._options = None
  _USERMEMBERSHIP.fields_by_name['user']._serialized_options = b'\340A\003'
  _USERMEMBERSHIP.fields_by_name['organization']._options = None
  _USERMEMBERSHIP.fields_by_name['organization']._serialized_options = b'\340A\003'
  _LISTUSERMEMBERSHIPSREQUEST.fields_by_name['user_id']._options = None
  _LISTUSERMEMBERSHIPSREQUEST.fields_by_name['user_id']._serialized_options = b'\340A\002'
  _LISTUSERMEMBERSHIPSRESPONSE.fields_by_name['memberships']._options = None
  _LISTUSERMEMBERSHIPSRESPONSE.fields_by_name['memberships']._serialized_options = b'\340A\003'
  _GETUSERMEMBERSHIPREQUEST.fields_by_name['view']._options = None
  _GETUSERMEMBERSHIPREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _GETUSERMEMBERSHIPREQUEST.fields_by_name['user_id']._options = None
  _GETUSERMEMBERSHIPREQUEST.fields_by_name['user_id']._serialized_options = b'\340A\002'
  _GETUSERMEMBERSHIPREQUEST.fields_by_name['organization_id']._options = None
  _GETUSERMEMBERSHIPREQUEST.fields_by_name['organization_id']._serialized_options = b'\340A\002'
  _GETUSERMEMBERSHIPRESPONSE.fields_by_name['membership']._options = None
  _GETUSERMEMBERSHIPRESPONSE.fields_by_name['membership']._serialized_options = b'\340A\003'
  _UPDATEUSERMEMBERSHIPREQUEST.fields_by_name['membership']._options = None
  _UPDATEUSERMEMBERSHIPREQUEST.fields_by_name['membership']._serialized_options = b'\340A\002'
  _UPDATEUSERMEMBERSHIPREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEUSERMEMBERSHIPREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _UPDATEUSERMEMBERSHIPREQUEST.fields_by_name['user_id']._options = None
  _UPDATEUSERMEMBERSHIPREQUEST.fields_by_name['user_id']._serialized_options = b'\340A\002'
  _UPDATEUSERMEMBERSHIPREQUEST.fields_by_name['organization_id']._options = None
  _UPDATEUSERMEMBERSHIPREQUEST.fields_by_name['organization_id']._serialized_options = b'\340A\002'
  _UPDATEUSERMEMBERSHIPRESPONSE.fields_by_name['membership']._options = None
  _UPDATEUSERMEMBERSHIPRESPONSE.fields_by_name['membership']._serialized_options = b'\340A\003'
  _DELETEUSERMEMBERSHIPREQUEST.fields_by_name['user_id']._options = None
  _DELETEUSERMEMBERSHIPREQUEST.fields_by_name['user_id']._serialized_options = b'\340A\002'
  _DELETEUSERMEMBERSHIPREQUEST.fields_by_name['organization_id']._options = None
  _DELETEUSERMEMBERSHIPREQUEST.fields_by_name['organization_id']._serialized_options = b'\340A\002'
  _LISTORGANIZATIONMEMBERSHIPSREQUEST.fields_by_name['organization_id']._options = None
  _LISTORGANIZATIONMEMBERSHIPSREQUEST.fields_by_name['organization_id']._serialized_options = b'\340A\002'
  _LISTORGANIZATIONMEMBERSHIPSRESPONSE.fields_by_name['memberships']._options = None
  _LISTORGANIZATIONMEMBERSHIPSRESPONSE.fields_by_name['memberships']._serialized_options = b'\340A\003'
  _GETORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['view']._options = None
  _GETORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _GETORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['organization_id']._options = None
  _GETORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['organization_id']._serialized_options = b'\340A\002'
  _GETORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['user_id']._options = None
  _GETORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['user_id']._serialized_options = b'\340A\002'
  _GETORGANIZATIONMEMBERSHIPRESPONSE.fields_by_name['membership']._options = None
  _GETORGANIZATIONMEMBERSHIPRESPONSE.fields_by_name['membership']._serialized_options = b'\340A\003'
  _UPDATEORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['membership']._options = None
  _UPDATEORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['membership']._serialized_options = b'\340A\002'
  _UPDATEORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _UPDATEORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['organization_id']._options = None
  _UPDATEORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['organization_id']._serialized_options = b'\340A\002'
  _UPDATEORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['user_id']._options = None
  _UPDATEORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['user_id']._serialized_options = b'\340A\002'
  _UPDATEORGANIZATIONMEMBERSHIPRESPONSE.fields_by_name['membership']._options = None
  _UPDATEORGANIZATIONMEMBERSHIPRESPONSE.fields_by_name['membership']._serialized_options = b'\340A\003'
  _DELETEORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['organization_id']._options = None
  _DELETEORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['organization_id']._serialized_options = b'\340A\002'
  _DELETEORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['user_id']._options = None
  _DELETEORGANIZATIONMEMBERSHIPREQUEST.fields_by_name['user_id']._serialized_options = b'\340A\002'
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['product_name']._options = None
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['product_name']._serialized_options = b'\340A\003'
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['id']._options = None
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['id']._serialized_options = b'\340A\003'
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['item_id']._options = None
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['item_id']._serialized_options = b'\340A\003'
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['price']._options = None
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['price']._serialized_options = b'\340A\003'
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['canceled_at']._options = None
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['canceled_at']._serialized_options = b'\340A\003'
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['trial_end']._options = None
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['trial_end']._serialized_options = b'\340A\003'
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['status']._options = None
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['status']._serialized_options = b'\340A\003'
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['description']._options = None
  _STRIPESUBSCRIPTIONDETAIL.fields_by_name['description']._serialized_options = b'\340A\003'
  _USERSUBSCRIPTION.fields_by_name['plan']._options = None
  _USERSUBSCRIPTION.fields_by_name['plan']._serialized_options = b'\340A\003'
  _USERSUBSCRIPTION.fields_by_name['detail']._options = None
  _USERSUBSCRIPTION.fields_by_name['detail']._serialized_options = b'\340A\003'
  _ORGANIZATIONSUBSCRIPTION.fields_by_name['plan']._options = None
  _ORGANIZATIONSUBSCRIPTION.fields_by_name['plan']._serialized_options = b'\340A\003'
  _ORGANIZATIONSUBSCRIPTION.fields_by_name['detail']._options = None
  _ORGANIZATIONSUBSCRIPTION.fields_by_name['detail']._serialized_options = b'\340A\003'
  _ORGANIZATIONSUBSCRIPTION.fields_by_name['used_seats']._options = None
  _ORGANIZATIONSUBSCRIPTION.fields_by_name['used_seats']._serialized_options = b'\340A\003'
  _GETAUTHENTICATEDUSERSUBSCRIPTIONRESPONSE.fields_by_name['subscription']._options = None
  _GETAUTHENTICATEDUSERSUBSCRIPTIONRESPONSE.fields_by_name['subscription']._serialized_options = b'\340A\003'
  _GETORGANIZATIONSUBSCRIPTIONREQUEST.fields_by_name['organization_id']._options = None
  _GETORGANIZATIONSUBSCRIPTIONREQUEST.fields_by_name['organization_id']._serialized_options = b'\340A\002'
  _GETORGANIZATIONSUBSCRIPTIONRESPONSE.fields_by_name['subscription']._options = None
  _GETORGANIZATIONSUBSCRIPTIONRESPONSE.fields_by_name['subscription']._serialized_options = b'\340A\003'
  _globals['_VIEW']._serialized_start=15649
  _globals['_VIEW']._serialized_end=15708
  _globals['_OWNERTYPE']._serialized_start=15710
  _globals['_OWNERTYPE']._serialized_end=15799
  _globals['_MEMBERSHIPSTATE']._serialized_start=15801
  _globals['_MEMBERSHIPSTATE']._serialized_end=15911
  _globals['_ONBOARDINGSTATUS']._serialized_start=15913
  _globals['_ONBOARDINGSTATUS']._serialized_end=16034
  _globals['_LIVENESSREQUEST']._serialized_start=270
  _globals['_LIVENESSREQUEST']._serialized_end=419
  _globals['_LIVENESSRESPONSE']._serialized_start=421
  _globals['_LIVENESSRESPONSE']._serialized_end=544
  _globals['_READINESSREQUEST']._serialized_start=547
  _globals['_READINESSREQUEST']._serialized_end=697
  _globals['_READINESSRESPONSE']._serialized_start=699
  _globals['_READINESSRESPONSE']._serialized_end=823
  _globals['_PERMISSION']._serialized_start=825
  _globals['_PERMISSION']._serialized_end=869
  _globals['_USERPROFILE']._serialized_start=872
  _globals['_USERPROFILE']._serialized_end=1333
  _globals['_USERPROFILE_SOCIALPROFILELINKSENTRY']._serialized_start=1194
  _globals['_USERPROFILE_SOCIALPROFILELINKSENTRY']._serialized_end=1263
  _globals['_ORGANIZATIONPROFILE']._serialized_start=1336
  _globals['_ORGANIZATIONPROFILE']._serialized_end=1751
  _globals['_ORGANIZATIONPROFILE_SOCIALPROFILELINKSENTRY']._serialized_start=1194
  _globals['_ORGANIZATIONPROFILE_SOCIALPROFILELINKSENTRY']._serialized_end=1263
  _globals['_AUTHENTICATEDUSER']._serialized_start=1754
  _globals['_AUTHENTICATEDUSER']._serialized_end=2404
  _globals['_OWNER']._serialized_start=2407
  _globals['_OWNER']._serialized_end=2549
  _globals['_USER']._serialized_start=2552
  _globals['_USER']._serialized_end=2892
  _globals['_LISTUSERSADMINREQUEST']._serialized_start=2895
  _globals['_LISTUSERSADMINREQUEST']._serialized_end=3135
  _globals['_LISTUSERSADMINRESPONSE']._serialized_start=3138
  _globals['_LISTUSERSADMINRESPONSE']._serialized_end=3279
  _globals['_GETUSERADMINREQUEST']._serialized_start=3281
  _globals['_GETUSERADMINREQUEST']._serialized_end=3391
  _globals['_GETUSERADMINRESPONSE']._serialized_start=3393
  _globals['_GETUSERADMINRESPONSE']._serialized_end=3459
  _globals['_LOOKUPUSERADMINREQUEST']._serialized_start=3461
  _globals['_LOOKUPUSERADMINREQUEST']._serialized_end=3576
  _globals['_LOOKUPUSERADMINRESPONSE']._serialized_start=3578
  _globals['_LOOKUPUSERADMINRESPONSE']._serialized_end=3647
  _globals['_LISTORGANIZATIONSADMINREQUEST']._serialized_start=3650
  _globals['_LISTORGANIZATIONSADMINREQUEST']._serialized_end=3878
  _globals['_LISTORGANIZATIONSADMINRESPONSE']._serialized_start=3881
  _globals['_LISTORGANIZATIONSADMINRESPONSE']._serialized_end=4054
  _globals['_GETORGANIZATIONADMINREQUEST']._serialized_start=4057
  _globals['_GETORGANIZATIONADMINREQUEST']._serialized_end=4191
  _globals['_GETORGANIZATIONADMINRESPONSE']._serialized_start=4193
  _globals['_GETORGANIZATIONADMINRESPONSE']._serialized_end=4291
  _globals['_LOOKUPORGANIZATIONADMINREQUEST']._serialized_start=4294
  _globals['_LOOKUPORGANIZATIONADMINREQUEST']._serialized_end=4433
  _globals['_LOOKUPORGANIZATIONADMINRESPONSE']._serialized_start=4435
  _globals['_LOOKUPORGANIZATIONADMINRESPONSE']._serialized_end=4536
  _globals['_LISTUSERSREQUEST']._serialized_start=4539
  _globals['_LISTUSERSREQUEST']._serialized_end=4774
  _globals['_LISTUSERSRESPONSE']._serialized_start=4777
  _globals['_LISTUSERSRESPONSE']._serialized_end=4928
  _globals['_GETUSERREQUEST']._serialized_start=4931
  _globals['_GETUSERREQUEST']._serialized_end=5072
  _globals['_GETUSERRESPONSE']._serialized_start=5074
  _globals['_GETUSERRESPONSE']._serialized_end=5140
  _globals['_GETAUTHENTICATEDUSERREQUEST']._serialized_start=5142
  _globals['_GETAUTHENTICATEDUSERREQUEST']._serialized_end=5171
  _globals['_GETAUTHENTICATEDUSERRESPONSE']._serialized_start=5173
  _globals['_GETAUTHENTICATEDUSERRESPONSE']._serialized_end=5265
  _globals['_PATCHAUTHENTICATEDUSERREQUEST']._serialized_start=5268
  _globals['_PATCHAUTHENTICATEDUSERREQUEST']._serialized_end=5427
  _globals['_PATCHAUTHENTICATEDUSERRESPONSE']._serialized_start=5429
  _globals['_PATCHAUTHENTICATEDUSERRESPONSE']._serialized_end=5523
  _globals['_CHECKNAMESPACEREQUEST']._serialized_start=5525
  _globals['_CHECKNAMESPACEREQUEST']._serialized_end=5569
  _globals['_CHECKNAMESPACERESPONSE']._serialized_start=5572
  _globals['_CHECKNAMESPACERESPONSE']._serialized_end=5806
  _globals['_CHECKNAMESPACERESPONSE_NAMESPACE']._serialized_start=5671
  _globals['_CHECKNAMESPACERESPONSE_NAMESPACE']._serialized_end=5806
  _globals['_CHECKNAMESPACEADMINREQUEST']._serialized_start=5808
  _globals['_CHECKNAMESPACEADMINREQUEST']._serialized_end=5857
  _globals['_CHECKNAMESPACEADMINRESPONSE']._serialized_start=5860
  _globals['_CHECKNAMESPACEADMINRESPONSE']._serialized_end=6247
  _globals['_CHECKNAMESPACEADMINRESPONSE_NAMESPACE']._serialized_start=5671
  _globals['_CHECKNAMESPACEADMINRESPONSE_NAMESPACE']._serialized_end=5806
  _globals['_CHECKNAMESPACEBYUIDADMINREQUEST']._serialized_start=6249
  _globals['_CHECKNAMESPACEBYUIDADMINREQUEST']._serialized_end=6305
  _globals['_CHECKNAMESPACEBYUIDADMINRESPONSE']._serialized_start=6308
  _globals['_CHECKNAMESPACEBYUIDADMINRESPONSE']._serialized_end=6703
  _globals['_CHECKNAMESPACEBYUIDADMINRESPONSE_NAMESPACE']._serialized_start=5671
  _globals['_CHECKNAMESPACEBYUIDADMINRESPONSE_NAMESPACE']._serialized_end=5806
  _globals['_APITOKEN']._serialized_start=6706
  _globals['_APITOKEN']._serialized_end=7341
  _globals['_APITOKEN_STATE']._serialized_start=7208
  _globals['_APITOKEN_STATE']._serialized_end=7295
  _globals['_CREATETOKENREQUEST']._serialized_start=7343
  _globals['_CREATETOKENREQUEST']._serialized_end=7413
  _globals['_CREATETOKENRESPONSE']._serialized_start=7415
  _globals['_CREATETOKENRESPONSE']._serialized_end=7491
  _globals['_LISTTOKENSREQUEST']._serialized_start=7494
  _globals['_LISTTOKENSREQUEST']._serialized_end=7622
  _globals['_LISTTOKENSRESPONSE']._serialized_start=7625
  _globals['_LISTTOKENSRESPONSE']._serialized_end=7768
  _globals['_GETTOKENREQUEST']._serialized_start=7770
  _globals['_GETTOKENREQUEST']._serialized_end=7855
  _globals['_GETTOKENRESPONSE']._serialized_start=7857
  _globals['_GETTOKENRESPONSE']._serialized_end=7930
  _globals['_DELETETOKENREQUEST']._serialized_start=7932
  _globals['_DELETETOKENREQUEST']._serialized_end=8020
  _globals['_DELETETOKENRESPONSE']._serialized_start=8022
  _globals['_DELETETOKENRESPONSE']._serialized_end=8043
  _globals['_VALIDATETOKENREQUEST']._serialized_start=8045
  _globals['_VALIDATETOKENREQUEST']._serialized_end=8067
  _globals['_VALIDATETOKENRESPONSE']._serialized_start=8069
  _globals['_VALIDATETOKENRESPONSE']._serialized_end=8124
  _globals['_GETREMAININGCREDITREQUEST']._serialized_start=8126
  _globals['_GETREMAININGCREDITREQUEST']._serialized_end=8199
  _globals['_GETREMAININGCREDITRESPONSE']._serialized_start=8202
  _globals['_GETREMAININGCREDITRESPONSE']._serialized_end=8341
  _globals['_GETREMAININGCREDITADMINREQUEST']._serialized_start=8343
  _globals['_GETREMAININGCREDITADMINREQUEST']._serialized_end=8418
  _globals['_GETREMAININGCREDITADMINRESPONSE']._serialized_start=8420
  _globals['_GETREMAININGCREDITADMINRESPONSE']._serialized_end=8477
  _globals['_SUBTRACTCREDITADMINREQUEST']._serialized_start=8479
  _globals['_SUBTRACTCREDITADMINREQUEST']._serialized_end=8600
  _globals['_SUBTRACTCREDITADMINRESPONSE']._serialized_start=8602
  _globals['_SUBTRACTCREDITADMINRESPONSE']._serialized_end=8655
  _globals['_AUTHTOKENISSUERREQUEST']._serialized_start=8657
  _globals['_AUTHTOKENISSUERREQUEST']._serialized_end=8747
  _globals['_AUTHTOKENISSUERRESPONSE']._serialized_start=8750
  _globals['_AUTHTOKENISSUERRESPONSE']._serialized_end=8986
  _globals['_AUTHTOKENISSUERRESPONSE_UNSIGNEDACCESSTOKEN']._serialized_start=8875
  _globals['_AUTHTOKENISSUERRESPONSE_UNSIGNEDACCESSTOKEN']._serialized_end=8986
  _globals['_AUTHLOGINREQUEST']._serialized_start=8988
  _globals['_AUTHLOGINREQUEST']._serialized_end=9072
  _globals['_AUTHLOGINRESPONSE']._serialized_start=9074
  _globals['_AUTHLOGINRESPONSE']._serialized_end=9128
  _globals['_AUTHLOGOUTREQUEST']._serialized_start=9130
  _globals['_AUTHLOGOUTREQUEST']._serialized_end=9149
  _globals['_AUTHLOGOUTRESPONSE']._serialized_start=9151
  _globals['_AUTHLOGOUTRESPONSE']._serialized_end=9171
  _globals['_AUTHVALIDATEACCESSTOKENREQUEST']._serialized_start=9173
  _globals['_AUTHVALIDATEACCESSTOKENREQUEST']._serialized_end=9205
  _globals['_AUTHVALIDATEACCESSTOKENRESPONSE']._serialized_start=9207
  _globals['_AUTHVALIDATEACCESSTOKENRESPONSE']._serialized_end=9240
  _globals['_AUTHCHANGEPASSWORDREQUEST']._serialized_start=9242
  _globals['_AUTHCHANGEPASSWORDREQUEST']._serialized_end=9339
  _globals['_AUTHCHANGEPASSWORDRESPONSE']._serialized_start=9341
  _globals['_AUTHCHANGEPASSWORDRESPONSE']._serialized_end=9369
  _globals['_ORGANIZATION']._serialized_start=9372
  _globals['_ORGANIZATION']._serialized_end=9844
  _globals['_LISTORGANIZATIONSREQUEST']._serialized_start=9847
  _globals['_LISTORGANIZATIONSREQUEST']._serialized_end=10090
  _globals['_LISTORGANIZATIONSRESPONSE']._serialized_start=10093
  _globals['_LISTORGANIZATIONSRESPONSE']._serialized_end=10276
  _globals['_CREATEORGANIZATIONREQUEST']._serialized_start=10278
  _globals['_CREATEORGANIZATIONREQUEST']._serialized_end=10373
  _globals['_CREATEORGANIZATIONRESPONSE']._serialized_start=10375
  _globals['_CREATEORGANIZATIONRESPONSE']._serialized_end=10476
  _globals['_GETORGANIZATIONREQUEST']._serialized_start=10479
  _globals['_GETORGANIZATIONREQUEST']._serialized_end=10652
  _globals['_GETORGANIZATIONRESPONSE']._serialized_start=10654
  _globals['_GETORGANIZATIONRESPONSE']._serialized_end=10752
  _globals['_UPDATEORGANIZATIONREQUEST']._serialized_start=10755
  _globals['_UPDATEORGANIZATIONREQUEST']._serialized_end=10962
  _globals['_UPDATEORGANIZATIONRESPONSE']._serialized_start=10964
  _globals['_UPDATEORGANIZATIONRESPONSE']._serialized_end=11065
  _globals['_DELETEORGANIZATIONREQUEST']._serialized_start=11067
  _globals['_DELETEORGANIZATIONREQUEST']._serialized_end=11180
  _globals['_DELETEORGANIZATIONRESPONSE']._serialized_start=11182
  _globals['_DELETEORGANIZATIONRESPONSE']._serialized_end=11210
  _globals['_ORGANIZATIONMEMBERSHIP']._serialized_start=11213
  _globals['_ORGANIZATIONMEMBERSHIP']._serialized_end=11508
  _globals['_USERMEMBERSHIP']._serialized_start=11511
  _globals['_USERMEMBERSHIP']._serialized_end=11790
  _globals['_LISTUSERMEMBERSHIPSREQUEST']._serialized_start=11792
  _globals['_LISTUSERMEMBERSHIPSREQUEST']._serialized_end=11856
  _globals['_LISTUSERMEMBERSHIPSRESPONSE']._serialized_start=11858
  _globals['_LISTUSERMEMBERSHIPSRESPONSE']._serialized_end=11960
  _globals['_GETUSERMEMBERSHIPREQUEST']._serialized_start=11963
  _globals['_GETUSERMEMBERSHIPREQUEST']._serialized_end=12134
  _globals['_GETUSERMEMBERSHIPRESPONSE']._serialized_start=12136
  _globals['_GETUSERMEMBERSHIPRESPONSE']._serialized_end=12234
  _globals['_UPDATEUSERMEMBERSHIPREQUEST']._serialized_start=12237
  _globals['_UPDATEUSERMEMBERSHIPREQUEST']._serialized_end=12479
  _globals['_UPDATEUSERMEMBERSHIPRESPONSE']._serialized_start=12481
  _globals['_UPDATEUSERMEMBERSHIPRESPONSE']._serialized_end=12582
  _globals['_DELETEUSERMEMBERSHIPREQUEST']._serialized_start=12584
  _globals['_DELETEUSERMEMBERSHIPREQUEST']._serialized_end=12695
  _globals['_DELETEUSERMEMBERSHIPRESPONSE']._serialized_start=12697
  _globals['_DELETEUSERMEMBERSHIPRESPONSE']._serialized_end=12727
  _globals['_LISTORGANIZATIONMEMBERSHIPSREQUEST']._serialized_start=12729
  _globals['_LISTORGANIZATIONMEMBERSHIPSREQUEST']._serialized_end=12817
  _globals['_LISTORGANIZATIONMEMBERSHIPSRESPONSE']._serialized_start=12819
  _globals['_LISTORGANIZATIONMEMBERSHIPSRESPONSE']._serialized_end=12937
  _globals['_GETORGANIZATIONMEMBERSHIPREQUEST']._serialized_start=12940
  _globals['_GETORGANIZATIONMEMBERSHIPREQUEST']._serialized_end=13119
  _globals['_GETORGANIZATIONMEMBERSHIPRESPONSE']._serialized_start=13121
  _globals['_GETORGANIZATIONMEMBERSHIPRESPONSE']._serialized_end=13235
  _globals['_UPDATEORGANIZATIONMEMBERSHIPREQUEST']._serialized_start=13238
  _globals['_UPDATEORGANIZATIONMEMBERSHIPREQUEST']._serialized_end=13496
  _globals['_UPDATEORGANIZATIONMEMBERSHIPRESPONSE']._serialized_start=13498
  _globals['_UPDATEORGANIZATIONMEMBERSHIPRESPONSE']._serialized_end=13615
  _globals['_DELETEORGANIZATIONMEMBERSHIPREQUEST']._serialized_start=13617
  _globals['_DELETEORGANIZATIONMEMBERSHIPREQUEST']._serialized_end=13736
  _globals['_DELETEORGANIZATIONMEMBERSHIPRESPONSE']._serialized_start=13738
  _globals['_DELETEORGANIZATIONMEMBERSHIPRESPONSE']._serialized_end=13776
  _globals['_STRIPESUBSCRIPTIONDETAIL']._serialized_start=13779
  _globals['_STRIPESUBSCRIPTIONDETAIL']._serialized_end=14363
  _globals['_STRIPESUBSCRIPTIONDETAIL_STATUS']._serialized_start=14127
  _globals['_STRIPESUBSCRIPTIONDETAIL_STATUS']._serialized_end=14333
  _globals['_USERSUBSCRIPTION']._serialized_start=14366
  _globals['_USERSUBSCRIPTION']._serialized_end=14582
  _globals['_USERSUBSCRIPTION_PLAN']._serialized_start=14525
  _globals['_USERSUBSCRIPTION_PLAN']._serialized_end=14582
  _globals['_ORGANIZATIONSUBSCRIPTION']._serialized_start=14585
  _globals['_ORGANIZATIONSUBSCRIPTION']._serialized_end=14881
  _globals['_ORGANIZATIONSUBSCRIPTION_PLAN']._serialized_start=14796
  _globals['_ORGANIZATIONSUBSCRIPTION_PLAN']._serialized_end=14875
  _globals['_GETAUTHENTICATEDUSERSUBSCRIPTIONREQUEST']._serialized_start=14883
  _globals['_GETAUTHENTICATEDUSERSUBSCRIPTIONREQUEST']._serialized_end=14924
  _globals['_GETAUTHENTICATEDUSERSUBSCRIPTIONRESPONSE']._serialized_start=14926
  _globals['_GETAUTHENTICATEDUSERSUBSCRIPTIONRESPONSE']._serialized_end=15045
  _globals['_GETORGANIZATIONSUBSCRIPTIONREQUEST']._serialized_start=15047
  _globals['_GETORGANIZATIONSUBSCRIPTIONREQUEST']._serialized_end=15135
  _globals['_GETORGANIZATIONSUBSCRIPTIONRESPONSE']._serialized_start=15137
  _globals['_GETORGANIZATIONSUBSCRIPTIONRESPONSE']._serialized_end=15259
  _globals['_GETUSERSUBSCRIPTIONADMINREQUEST']._serialized_start=15261
  _globals['_GETUSERSUBSCRIPTIONADMINREQUEST']._serialized_end=15325
  _globals['_GETUSERSUBSCRIPTIONADMINRESPONSE']._serialized_start=15327
  _globals['_GETUSERSUBSCRIPTIONADMINRESPONSE']._serialized_end=15433
  _globals['_GETORGANIZATIONSUBSCRIPTIONADMINREQUEST']._serialized_start=15435
  _globals['_GETORGANIZATIONSUBSCRIPTIONADMINREQUEST']._serialized_end=15523
  _globals['_GETORGANIZATIONSUBSCRIPTIONADMINRESPONSE']._serialized_start=15525
  _globals['_GETORGANIZATIONSUBSCRIPTIONADMINRESPONSE']._serialized_end=15647
# @@protoc_insertion_point(module_scope)
